@@ -1,26 +1,78 @@
-import csv
 import codecs
+import csv
 import logging
 
 from django import forms
 from django.contrib.auth.forms import UserCreationForm
+from django.core.exceptions import ValidationError
+from django.core.validators import MaxLengthValidator, MaxValueValidator, MinLengthValidator, MinValueValidator
+from django.db import IntegrityError
 from django.forms.models import model_to_dict
 from django.utils.translation import gettext_lazy as _
-from django.db import IntegrityError
-from django.core.exceptions import ValidationError
-from django.core.validators import MaxValueValidator, MinValueValidator, MaxLengthValidator, MinLengthValidator
+
 from djmoney.money import Money
 
-from .constants import VALUE_UNITS, PACKAGE_TYPES, POWER_UNITS, INTERFACE_TYPES, TEMPERATURE_UNITS, DISTANCE_UNITS, WAVELENGTH_UNITS, \
-    WEIGHT_UNITS, FREQUENCY_UNITS, VOLTAGE_UNITS, CURRENT_UNITS, MEMORY_UNITS, SUBSCRIPTION_TYPES, ROLE_TYPES, CONFIGURATION_TYPES, NUMBER_SCHEME_SEMI_INTELLIGENT, \
-    NUMBER_SCHEME_INTELLIGENT, ROLE_TYPE_VIEWER, NUMBER_CLASS_CODE_LEN_DEFAULT, NUMBER_CLASS_CODE_LEN_MIN, NUMBER_CLASS_CODE_LEN_MAX, \
-    NUMBER_ITEM_LEN_DEFAULT, NUMBER_ITEM_LEN_MIN, NUMBER_ITEM_LEN_MAX, NUMBER_VARIATION_LEN_DEFAULT, NUMBER_VARIATION_LEN_MIN, NUMBER_VARIATION_LEN_MAX
+from .constants import (
+    CONFIGURATION_TYPES,
+    CURRENT_UNITS,
+    DISTANCE_UNITS,
+    FREQUENCY_UNITS,
+    INTERFACE_TYPES,
+    MEMORY_UNITS,
+    NUMBER_CLASS_CODE_LEN_DEFAULT,
+    NUMBER_CLASS_CODE_LEN_MAX,
+    NUMBER_CLASS_CODE_LEN_MIN,
+    NUMBER_ITEM_LEN_DEFAULT,
+    NUMBER_ITEM_LEN_MAX,
+    NUMBER_ITEM_LEN_MIN,
+    NUMBER_SCHEME_INTELLIGENT,
+    NUMBER_SCHEME_SEMI_INTELLIGENT,
+    NUMBER_VARIATION_LEN_DEFAULT,
+    NUMBER_VARIATION_LEN_MAX,
+    NUMBER_VARIATION_LEN_MIN,
+    PACKAGE_TYPES,
+    POWER_UNITS,
+    ROLE_TYPE_VIEWER,
+    ROLE_TYPES,
+    SUBSCRIPTION_TYPES,
+    TEMPERATURE_UNITS,
+    VALUE_UNITS,
+    VOLTAGE_UNITS,
+    WAVELENGTH_UNITS,
+    WEIGHT_UNITS,
+)
+from .csv_headers import (
+    BOMFlatCSVHeaders,
+    BOMIndentedCSVHeaders,
+    CSVHeaderError,
+    PartClassesCSVHeaders,
+    PartsListCSVHeaders,
+)
 from .form_fields import AutocompleteTextInput
-from .models import Part, PartClass, Manufacturer, ManufacturerPart, Subpart, Seller, SellerPart, User, UserMeta, \
-    Organization, PartRevision, AssemblySubparts, Assembly
-from .validators import decimal, numeric, alphanumeric
-from .utils import listify_string, stringify_list, check_references_for_duplicates, prep_for_sorting_nicely, get_from_dict
-from .csv_headers import PartsListCSVHeaders, PartClassesCSVHeaders, BOMFlatCSVHeaders, BOMIndentedCSVHeaders, CSVHeaderError
+from .models import (
+    Assembly,
+    AssemblySubparts,
+    Manufacturer,
+    ManufacturerPart,
+    Organization,
+    Part,
+    PartClass,
+    PartRevision,
+    Seller,
+    SellerPart,
+    Subpart,
+    User,
+    UserMeta,
+)
+from .utils import (
+    check_references_for_duplicates,
+    get_from_dict,
+    listify_string,
+    prep_for_sorting_nicely,
+    stringify_list,
+)
+from .validators import alphanumeric, decimal, numeric
+
 
 logger = logging.getLogger(__name__)
 
@@ -151,7 +203,7 @@ class OrganizationCreateForm(forms.ModelForm):
 class OrganizationForm(forms.ModelForm):
     class Meta:
         model = Organization
-        exclude = ['owner', 'subscription', 'google_drive_parent', 'number_scheme', ]
+        exclude = ['owner', 'subscription', 'subscription_quantity', 'google_drive_parent', 'number_scheme', ]
         labels = {
             "name": "Organization Name",
             "number_class_code_len": "Number Class Code Length (C)",
@@ -176,7 +228,7 @@ class OrganizationFormEditSettings(OrganizationForm):
 
     class Meta:
         model = Organization
-        exclude = ['subscription', 'google_drive_parent', 'number_scheme', 'number_item_len', 'number_class_code_len', 'number_variation_len', 'owner', ]
+        exclude = ['subscription', 'subscription_quantity', 'google_drive_parent', 'number_scheme', 'number_item_len', 'number_class_code_len', 'number_variation_len', 'owner', ]
         labels = {
             "name": "Organization Name",
         }
@@ -231,12 +283,9 @@ class ManufacturerPartForm(forms.ModelForm):
 
 
 class SellerPartForm(forms.ModelForm):
-    unit_cost = forms.DecimalField(required=True, decimal_places=4, max_digits=17)
-    nre_cost = forms.DecimalField(required=True, decimal_places=4, max_digits=17, label='NRE cost')
-
     class Meta:
         model = SellerPart
-        exclude = ['manufacturer_part', 'data_source', 'unit_cost', 'nre_cost', ]
+        exclude = ['manufacturer_part', 'data_source', ]
 
     new_seller = forms.CharField(max_length=128, label='-or- Create new seller (leave blank if selecting)', required=False)
     field_order = ['seller', 'new_seller', 'unit_cost', 'nre_cost', 'lead_time_days', 'minimum_order_quantity', 'minimum_pack_quantity', ]
@@ -244,11 +293,19 @@ class SellerPartForm(forms.ModelForm):
     def __init__(self, *args, **kwargs):
         self.organization = kwargs.pop('organization', None)
         self.manufacturer_part = kwargs.pop('manufacturer_part', None)
+        self.base_fields['unit_cost'] = forms.DecimalField(required=True, decimal_places=4, max_digits=17)
+        self.base_fields['nre_cost'] = forms.DecimalField(required=True, decimal_places=4, max_digits=17, label='NRE cost')
+
+        instance = kwargs.get('instance')
+        if instance:
+            initial = kwargs.get('initial', {})
+            initial['unit_cost'] = instance.unit_cost.amount
+            initial['nre_cost'] = instance.nre_cost.amount
+            kwargs['initial'] = initial
         super(SellerPartForm, self).__init__(*args, **kwargs)
         if self.manufacturer_part is not None:
             self.instance.manufacturer_part = self.manufacturer_part
-        self.fields['seller'].queryset = Seller.objects.filter(
-            organization=self.organization).order_by('name')
+        self.fields['seller'].queryset = Seller.objects.filter(organization=self.organization).order_by('name')
         self.fields['seller'].required = False
 
     def clean(self):
@@ -403,9 +460,9 @@ class PartClassCSVForm(forms.Form):
                             code='invalid')
                         self.add_error(None, validation_error)
                         continue
-                    elif not code.isdigit() or int(code) < 0:
+                    elif len(code) != self.organization.number_class_code_len:
                         validation_error = forms.ValidationError(
-                            "Part class 'code' in row {} must be a positive number. Uploading of this part class skipped.".format(row_count),
+                            "Length of part class 'code' in row {} is different than the organization class length {}. Uploading of this part class skipped.".format(row_count, self.organization.number_class_code_len),
                             code='invalid')
                         self.add_error(None, validation_error)
                         continue
@@ -500,6 +557,11 @@ class PartCSVForm(forms.Form):
                 description = csv_headers.get_val_from_row(part_data, 'description')
                 value = csv_headers.get_val_from_row(part_data, 'value')
                 value_units = csv_headers.get_val_from_row(part_data, 'value_units')
+                seller_name = csv_headers.get_val_from_row(part_data, 'seller')
+                unit_cost = csv_headers.get_val_from_row(part_data, 'unit_cost')
+                nre_cost = csv_headers.get_val_from_row(part_data, 'part_nre_cost')
+                moq = csv_headers.get_val_from_row(part_data, 'moq')
+                mpq = csv_headers.get_val_from_row(part_data, 'minimum_pack_quantity')
 
                 # Check part number for uniqueness. If part number not specified
                 # then Part.save() will create one.
@@ -535,7 +597,10 @@ class PartCSVForm(forms.Form):
                                              "Uploading of this part skipped.".format(part_data[csv_headers.get_default('part_class')], row_count))
                         continue
                 else:
-                    self.add_error(None, "In row {} need to specify a part_class or a part_number. Uploading of this part skipped.".format(row_count))
+                    if self.organization.number_scheme == NUMBER_SCHEME_SEMI_INTELLIGENT:
+                        self.add_error(None, "In row {} need to specify a part_class or part_number. Uploading of this part skipped.".format(row_count))
+                    else:
+                        self.add_error(None, "In row {} need to specify a part_number. Uploading of this part skipped.".format(row_count))
                     continue
 
                 if not revision:
@@ -561,6 +626,7 @@ class PartCSVForm(forms.Form):
 
                 skip = False
                 part_revision = PartRevision()
+                part_revision.revision = revision
 
                 # Required properties:
                 if description is None:
@@ -665,6 +731,10 @@ class PartCSVForm(forms.Form):
                             part.primary_manufacturer_part = manufacturer_part
                             part.save()
 
+                        if seller_name and unit_cost and nre_cost:
+                            seller, created = Seller.objects.get_or_create(name__iexact=seller_name, organization=self.organization, defaults={'name': seller_name})
+                            seller_part, created = SellerPart.objects.get_or_create(manufacturer_part=manufacturer_part, seller=seller, unit_cost=unit_cost, nre_cost=nre_cost, minimum_order_quantity=moq, minimum_pack_quantity=mpq)
+
                     self.successes.append("Part {0} on row {1} created.".format(part.full_part_number(), row_count))
                 else:
                     for k, error in prf.errors.items():
