@@ -40,7 +40,7 @@ class MouserPartMatchBOM(BomJsonResponse):
             try:
                 part_seller_info = mouser.search_and_match(mp, quantity=bom_part_quantity, currency=organization.currency)
             except BaseApiError as err:
-                self.response['errors'].append(err)
+                self.response['errors'].append(str(err))
                 continue
 
             try:
