@@ -172,6 +172,7 @@ def home(request):
         response = HttpResponse(content_type='text/csv')
         response['Content-Disposition'] = 'attachment; filename="indabom_parts_search.csv"'
         csv_headers = organization.part_list_csv_headers()
+        seller_csv_headers = SellerPartCSVHeaders()
         writer = csv.DictWriter(response, fieldnames=csv_headers.get_default_all())
         writer.writeheader()
         for part_rev in part_revs:
@@ -185,7 +186,8 @@ def home(request):
                     csv_headers.get_default('part_manufacturer_part_number'): part_rev.part.primary_manufacturer_part.manufacturer_part_number if part_rev.part.primary_manufacturer_part is not None else '',
                 }
                 for field_name in csv_headers.get_default_all():
-                    if field_name not in csv_headers.get_defaults_list(['part_number', 'part_category', 'part_synopsis', 'part_revision', 'part_manufacturer', 'part_manufacturer_part_number', ]):
+                    if field_name not in csv_headers.get_defaults_list(['part_number', 'part_category', 'part_synopsis', 'part_revision', 'part_manufacturer', 'part_manufacturer_part_number', ]
+                                                                       + seller_csv_headers.get_default_all()):
                         attr = getattr(part_rev, field_name)
                         row.update({csv_headers.get_default(field_name): attr if attr is not None else ''})
             else:
@@ -197,10 +199,20 @@ def home(request):
                     csv_headers.get_default('part_manufacturer_part_number'): part_rev.part.primary_manufacturer_part.manufacturer_part_number if part_rev.part.primary_manufacturer_part is not None else '',
                 }
                 for field_name in csv_headers.get_default_all():
-                    if field_name not in csv_headers.get_defaults_list(['part_number', 'part_synopsis', 'part_revision', 'part_manufacturer', 'part_manufacturer_part_number', ]):
+                    if field_name not in csv_headers.get_defaults_list(['part_number', 'part_synopsis', 'part_revision', 'part_manufacturer', 'part_manufacturer_part_number', ]
+                                                                       + seller_csv_headers.get_default_all()):
                         attr = getattr(part_rev, field_name)
                         row.update({csv_headers.get_default(field_name): attr if attr is not None else ''})
-            writer.writerow({k: smart_str(v) for k, v in row.items()})
+
+            sellerparts = part_rev.part.seller_parts()
+            if len(sellerparts) > 0:
+                for sellerpart in part_rev.part.seller_parts():
+                    for field_name in seller_csv_headers.get_default_all():
+                        attr = getattr(sellerpart, field_name)
+                        row.update({csv_headers.get_default(field_name): attr if attr is not None else ''})
+                    writer.writerow({k: smart_str(v) for k, v in row.items()})
+            else:
+                writer.writerow({k: smart_str(v) for k, v in row.items()})
         return response
 
     paginator = Paginator(part_revs, 50)
